@@ -521,8 +521,11 @@ class JsonList(list):
 
     def to_dataframe(self):
         from pandas import DataFrame
-        columns = self.list_type().get_columns()
-        return DataFrame([i.get_values() for i in self], columns=columns)
+        if issubclass(self.list_type(), JsonObject):
+            columns = self.list_type().get_columns()
+            return DataFrame([i.__dataframe_values__() for i in self], columns=columns)
+        else:
+            return DataFrame(self)
 
     def from_dataframe(self, df):
         self.clear()
